# -*- coding: utf-8 -*-
# czifile.py

"""Proxy for the czifile module in the zisraw package."""

from zisraw.czifile import __doc__, __all__, __version__  # noqa
from zisraw.czifile import czi2tif  # noqa
from zisraw.czifile import *  # noqa



# -*- coding: utf-8 -*-
# czi2tif.py

"""Convert CZI file to memory-mappable BigTIFF file.

Usage: czi2tif czi_filename [tif_filename]

"""

import sys

try:
    from .czifile import czi2tif
except ImportError:
    from czifile import czi2tif


def main(argv=None):
    """Czi2tif command line usage main function."""
    if argv is None:
        argv = sys.argv
    if len(argv) > 1:
        truncate = '--truncate' in argv
        if truncate:
            argv.remove('--truncate')
        czi2tif(argv[1], argv[2] if len(argv) > 2 else None,
                bigtiff=True, truncate=truncate)
    else:
        print()
        print(__doc__)


if __name__ == '__main__':
    sys.exit(main())



# -*- coding: utf-8 -*-
# zisraw/setup.py

import sys
import re

from setuptools import setup

with open('zisraw/czifile.py') as fh:
    code = fh.read()

version = re.search(r"__version__ = '(.*?)'", code).groups()[0]
description = re.search(r'"""(.*)\.\n', code).groups()[0]
readme = re.search(r'[\r\n?|\n]{2}"""(.*)"""[\r\n?|\n]{2}from', code,
                   re.MULTILINE | re.DOTALL).groups()[0]
license = re.search(r'(# Copyright.*?[\r\n?|\n])[\r\n?|\n]+""', code,
                    re.MULTILINE | re.DOTALL).groups()[0]

readme = '\n'.join([description, '=' * len(description)]
                   + readme.splitlines()[1:])
license = license.replace('# ', '').replace('#', '')

if 'sdist' in sys.argv:
    with open('LICENSE', 'w') as fh:
        fh.write(license)
    with open('README.rst', 'w') as fh:
        fh.write(readme)

setup(
    name='zisraw',
    version=version,
    description=description,
    long_description=readme,
    author='Christoph Gohlke',
    author_email='cgohlke@uci.edu',
    url='https://www.lfd.uci.edu/~gohlke/',
    license='BSD',
    packages=['zisraw'],
    py_modules=['czifile'],
    python_requires='>=2.7',
    install_requires=[
        'numpy>=1.14',
        'scipy>=1.1',
        'tiffile>=2018.8.29',
        'imagecodecs>=2018.8.29'
        ],
    tests_require=['pytest'],
    entry_points={
        'console_scripts': [
            'czi2tif = zisraw.czi2tif:main'
            ]},
    platforms=['any'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: BSD License',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        ],
)
